q-functions
-----------

q-Pochhammer symbol
...................

.. autofunction:: mpmath.qp


q-gamma and factorial
.....................

.. autofunction:: mpmath.qgamma
.. autofunction:: mpmath.qfac


Hypergeometric q-series
.......................

.. autofunction:: mpmath.qhyper
